@@ -128,37 +128,25 @@ def auth(
     email: str, password: str, api_root: str = DEFAULT_API_ROOT, path: str = None
 ) -> None:
     """Q-CTRL Authentication setup.
+
     Provides default configuration for environmental authentication,
     allowing users to avoid managing in-script credentials. After this setup,
-    the Qctrl package can be used as below:
+    the Qctrl package can be used in a Python environment as below:
 
         \b
+        $ python
+        >>> from qctrl import Qctrl
+        >>> qctrl = Qctrl()
 
-    For instance based authentication, preferred for remote deployments or
+    For instance-based authentication, preferred for remote deployments or
     non-interactive environments, use the standard authentication method.
 
         \b
-
-    For more details, access our documentation at https://docs.q-ctrl.com
-
-    Parameters
-    ----------
-    email: str
-        linked account email address.
-    password: str
-        password for the account.
-    api_root: str, optional
-        qctrl host. (Default value="https://api.q-ctrl.com/")
-    path : str
-        path to your qctrl credential. (Default value = None)
-
-    Returns
-    -------
-    >>> from qctrl import Qctrl
-        >>> qctrl = Qctrl()
-
+        $ python
         >>> from qctrl import Qctrl
         >>> qctrl = Qctrl(email=..., password=...)
+
+    For more details, access our documentation at https://docs.q-ctrl.com
     """
 
     gql_annonymous_client = create_gql_client(api_root)
@@ -272,7 +260,7 @@ def gql_query(api_root, input, output):  # pylint:disable=redefined-builtin
     Runs gql query and return indented result.
     """
     gql_api = create_gql_client(api_root, create_client_auth(api_root))
-    with open(input, "r") as file:
+    with open(input, "r", encoding="utf-8") as file:
         query = file.read()
     result = gql_api.execute(gql(query))
 
