@@ -40,20 +40,6 @@ from qctrl import __version__
 LOGGER = logging.getLogger(__name__)
 
 
-class TokenError(QctrlException):
-    """Raised when token is invalid or expired."""
-
-    # pylint: disable=keyword-arg-before-vararg
-    def __init__(self, msg=None, *args, **kwargs):
-        if not msg:
-            msg = (
-                "An error occurred with your authentication session. Please try "
-                "again. If the issue persists, recreate your environment "
-                "authentication by running `qctrl auth` from the command line."
-            )
-        super().__init__(msg, *args, **kwargs)
-
-
 class VersionError(QctrlException):
     """Raised when QCTRL client version is incompatible with the API."""
 
